@@ -30,7 +30,7 @@ pub use self::{
         SequenceDataExchange,
     },
     duty::{AdultDuties, Duty, ElderDuties, NodeDuties},
-    errors::{Error, ErrorDebug, Result},
+    errors::{Error, Result},
     map::{MapRead, MapWrite},
     network::{
         NodeCmd, NodeCmdError, NodeDataError, NodeEvent, NodeQuery, NodeQueryResponse,
@@ -56,7 +56,6 @@ use sn_data_types::{
 use std::{
     collections::{BTreeMap, BTreeSet},
     convert::TryFrom,
-    fmt,
 };
 
 /// Message envelope containing a Safe message payload,
@@ -232,7 +231,7 @@ pub enum Event {
 
 /// Query responses from the network.
 #[allow(clippy::large_enum_variant, clippy::type_complexity)]
-#[derive(Eq, PartialEq, Clone, Serialize, Deserialize)]
+#[derive(Eq, PartialEq, Clone, Serialize, Deserialize, Debug)]
 pub enum QueryResponse {
     //
     // ===== Blob =====
@@ -296,7 +295,40 @@ pub enum QueryResponse {
     /// Get key transfer history.
     GetHistory(Result<ActorHistory>),
     /// Get Store Cost.
-    GetStoreCost(Result<Token>),
+    GetStoreCost(Result<(u64, Token, PublicKey)>),
+}
+
+impl QueryResponse {
+    /// Returns true if the result returned is a success or not
+    pub fn is_success(&self) -> bool {
+        use QueryResponse::*;
+        match self {
+            GetBlob(result) => result.is_ok(),
+            GetMap(result) => result.is_ok(),
+            GetMapShell(result) => result.is_ok(),
+            GetMapVersion(result) => result.is_ok(),
+            ListMapEntries(result) => result.is_ok(),
+            ListMapKeys(result) => result.is_ok(),
+            ListMapValues(result) => result.is_ok(),
+            ListMapUserPermissions(result) => result.is_ok(),
+            ListMapPermissions(result) => result.is_ok(),
+            GetMapValue(result) => result.is_ok(),
+            GetSequence(result) => result.is_ok(),
+            GetSequenceRange(result) => result.is_ok(),
+            GetSequenceLastEntry(result) => result.is_ok(),
+            GetSequencePublicPolicy(result) => result.is_ok(),
+            GetSequencePrivatePolicy(result) => result.is_ok(),
+            GetSequenceUserPermissions(result) => result.is_ok(),
+            GetRegister(result) => result.is_ok(),
+            GetRegisterOwner(result) => result.is_ok(),
+            ReadRegister(result) => result.is_ok(),
+            GetRegisterPolicy(result) => result.is_ok(),
+            GetRegisterUserPermissions(result) => result.is_ok(),
+            GetBalance(result) => result.is_ok(),
+            GetHistory(result) => result.is_ok(),
+            GetStoreCost(result) => result.is_ok(),
+        }
+    }
 }
 
 /// Error type for an attempted conversion from `QueryResponse` to a type implementing
@@ -350,81 +382,6 @@ try_from!(Permissions, GetRegisterUserPermissions);
 try_from!(Token, GetBalance);
 try_from!(ActorHistory, GetHistory);
 
-impl fmt::Debug for QueryResponse {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        use QueryResponse::*;
-
-        match self {
-            // Blob
-            GetBlob(res) => write!(f, "QueryResponse::GetBlob({:?})", ErrorDebug(res)),
-            // Map
-            GetMap(res) => write!(f, "QueryResponse::GetMap({:?})", ErrorDebug(res)),
-            GetMapShell(res) => write!(f, "QueryResponse::GetMapShell({:?})", ErrorDebug(res)),
-            GetMapVersion(res) => write!(f, "QueryResponse::GetMapVersion({:?})", ErrorDebug(res)),
-            ListMapEntries(res) => {
-                write!(f, "QueryResponse::ListMapEntries({:?})", ErrorDebug(res))
-            }
-            ListMapKeys(res) => write!(f, "QueryResponse::ListMapKeys({:?})", ErrorDebug(res)),
-            ListMapValues(res) => write!(f, "QueryResponse::ListMapValues({:?})", ErrorDebug(res)),
-            ListMapPermissions(res) => write!(
-                f,
-                "QueryResponse::ListMapPermissions({:?})",
-                ErrorDebug(res)
-            ),
-            ListMapUserPermissions(res) => write!(
-                f,
-                "QueryResponse::ListMapUserPermissions({:?})",
-                ErrorDebug(res)
-            ),
-            GetMapValue(res) => write!(f, "QueryResponse::GetMapValue({:?})", ErrorDebug(res)),
-            // Sequence
-            GetSequence(res) => write!(f, "QueryResponse::GetSequence({:?})", ErrorDebug(res)),
-            GetSequenceRange(res) => {
-                write!(f, "QueryResponse::GetSequenceRange({:?})", ErrorDebug(res))
-            }
-            GetSequenceLastEntry(res) => write!(
-                f,
-                "QueryResponse::GetSequenceLastEntry({:?})",
-                ErrorDebug(res)
-            ),
-            GetSequenceUserPermissions(res) => write!(
-                f,
-                "QueryResponse::GetSequenceUserPermissions({:?})",
-                ErrorDebug(res)
-            ),
-            GetSequencePublicPolicy(res) => write!(
-                f,
-                "QueryResponse::GetSequencePublicPolicy({:?})",
-                ErrorDebug(res)
-            ),
-            GetSequencePrivatePolicy(res) => write!(
-                f,
-                "QueryResponse::GetSequencePrivatePolicy({:?})",
-                ErrorDebug(res)
-            ),
-            // Register
-            GetRegister(res) => write!(f, "QueryResponse::GetRegister({:?})", ErrorDebug(res)),
-            ReadRegister(res) => {
-                write!(f, "QueryResponse::ReadRegister({:?})", ErrorDebug(res))
-            }
-            GetRegisterUserPermissions(res) => write!(
-                f,
-                "QueryResponse::GetRegisterUserPermissions({:?})",
-                ErrorDebug(res)
-            ),
-            GetRegisterPolicy(res) => {
-                write!(f, "QueryResponse::GetRegisterPolicy({:?})", ErrorDebug(res))
-            }
-            GetRegisterOwner(res) => {
-                write!(f, "QueryResponse::GetRegisterOwner({:?})", ErrorDebug(res))
-            }
-            GetBalance(res) => write!(f, "QueryResponse::GetBalance({:?})", ErrorDebug(res)),
-            GetHistory(res) => write!(f, "QueryResponse::GetHistory({:?})", ErrorDebug(res)),
-            GetStoreCost(res) => write!(f, "QueryResponse::GetStoreCost({:?})", ErrorDebug(res)),
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -449,18 +406,6 @@ mod tests {
         gen_keypairs().iter().map(PublicKey::from).collect()
     }
 
-    #[test]
-    fn debug_format() -> Result<()> {
-        if let Some(key) = gen_keys().first() {
-            let errored_response = QueryResponse::GetSequence(Err(Error::AccessDenied(*key)));
-            assert!(format!("{:?}", errored_response)
-                .contains("QueryResponse::GetSequence(AccessDenied(PublicKey::"));
-            Ok(())
-        } else {
-            Err(anyhow!("Could not generate public key"))
-        }
-    }
-
     #[test]
     fn try_from() -> Result<()> {
         use QueryResponse::*;
